#!/bin/bash

if [ -x '/usr/bp/bin/bputil' ]
then
	NDMP_USER=$(/usr/bp/bin/bputil -g NDMP Username ndmp /usr/bp/bpinit/master.ini)
	NDMP_PASS=$(/usr/bp/bin/bputil -g NDMP Password unitrendsndmp /usr/bp/bpinit/master.ini)
else
	NDMP_USER=ndmp
	NDMP_PASS=unitrendsndmp
fi

# Add -d to expect for debug output
expect -c "  
	log_user 0
	set timeout 60
	spawn /usr/bp/bin/ndmp/ndmpadm enable -a cram-md5 -u $NDMP_USER
	expect -re \"Enter new password:\"
	send \"$NDMP_PASS\n\"
	expect -re \"Re-enter  password:\"
	send \"$NDMP_PASS\n\"
	expect eof"

# The value in master.ini takes precedence. If no value is found, try seth0 and eth0.
IPADDR_NDMP=$(/usr/bp/bin/bputil -g NDMP IPv4Address "" /usr/bp/bpinit/master.ini)
if [ -z ${IPADDR_NDMP} ]
then
	# Hyper-V on Centos 5 renames the ethernet device to seth0, so use that if appropriate.
	# Centos 6 builds do not do this and use eth0.
	# Centos 7 are in the format en* except on Hyper-V where they will be eth0.

	centos_version=$(uname -r | sed -e 's/.*el//' | cut -c1)

	if [ $centos_version -eq 6 ]
	then
		if ifconfig | grep -q "seth0"
		then
			IPADDR_NDMP=$(ifconfig seth0 | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}')
		elif ifconfig | grep -q "eth0"
		then
			IPADDR_NDMP=$(ifconfig eth0 | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}')
		else
			# gets first NIC IP on CentOS6 or CentOS7
			IPADDR_NDMP=$(ifconfig |grep 'inet ' |sed -e 's/.*inet //' -e 's/.*addr://' | awk '{ print $1 }' |head -n1)
		fi
	else
		# CentOS 7
		activeInterface=$(ip addr | grep -w inet |awk '{ print $NF }' | grep -E 'eth|en' | head -n1)
		IPADDR_NDMP=$(ifconfig $activeInterface | grep 'inet ' | cut -d: -f2 | awk '{print $2}')
	fi
fi

/usr/bp/bin/ndmp/ndmpadm set -p mover-nic=$IPADDR_NDMP

# sed cannot be safely used to perform a substitution with a variable because
# the variable is interpreted by the shell, not sed.
cp /usr/bp/bin/ndmp/ndmpd.conf /usr/bp/bin/ndmp/ndmpd.conf.old
awk -v IPADDR_NDMP="${IPADDR_NDMP}" '{
	sub(/mover-nic.*/, "mover-nic = \"" IPADDR_NDMP "\"");
	print;
}' /usr/bp/bin/ndmp/ndmpd.conf.old > /usr/bp/bin/ndmp/ndmpd.conf
